pub struct Button {
pub text: Option<String>,
/* private fields */
}Expand description
A basic button widget with an optional label.
A Widget that can be pressed and released and may emit an event on_press and on_release. The button can also be triggered with a keyboard key (default space bar).
Example
Create a button which closes the window when pressed:
Button::new()
.on_press(|_, state, button| {
button.emit(state, WindowEvent::CloseWindow);
})
.build(state, parent, |builder| builder);Fields
text: Option<String>Implementations
Sourceimpl Button
impl Button
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new button widget with no callbacks.
Example
Button::new().build(state, parent, |builder| builder);Sourcepub fn with_label(text: &str) -> Self
pub fn with_label(text: &str) -> Self
Create a new button widget with a specified text label.
Example
Button::with_label("A Button").build(state, parent, |builder| builder);Sourcepub fn on_press<F>(self, callback: F) -> Self
pub fn on_press<F>(self, callback: F) -> Self
Set the callback triggered when the button is pressed.
Example
Creates a button which closes the window when pressed:
Button::new()
.on_press(|_, state, button| {
button.emit(state, WindowEvent::CloseWindow);
})
.build(state, parent, |builder| builder);Sourcepub fn on_release<F>(self, callback: F) -> Self
pub fn on_release<F>(self, callback: F) -> Self
Set the callback triggered when the button is released.
Example
Create a button which closes the window when released:
Button::new()
.on_release(|_, state, button| {
button.emit(state, WindowEvent::CloseWindow);
})
.build(state, parent, |builder| builder);Trait Implementations
Sourceimpl Widget for Button
impl Widget for Button
type Ret = Entity
type Data = ()
fn widget_name(&self) -> String
fn on_build(&mut self, state: &mut State, entity: Entity) -> Self::Ret
fn on_event(&mut self, state: &mut State, entity: Entity, event: &mut Event)
Sourcefn build<F>(
self,
state: &mut State,
parent: impl AsEntity,
builder: F,
) -> Self::Ret
fn build<F>( self, state: &mut State, parent: impl AsEntity, builder: F, ) -> Self::Ret
Adds the widget into state and returns the associated type Ret - an entity id or a tuple of entity ids
fn bind<L, F>(self, lens: L, converter: F) -> Wrapper<L, Self>
fn bind2<L>(self, lens: L) -> LensWrap<L, Self>where
L: Lens,
fn on_update(&mut self, state: &mut State, entity: Entity, data: &Self::Data)
fn on_style( &mut self, state: &mut State, entity: Entity, property: (String, PropType), )
fn on_draw( &mut self, state: &mut State, entity: Entity, canvas: &mut Canvas<OpenGl>, )